#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- marginal means
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()
library(ggthemes)
options(stringsAsFactors = FALSE)

fig_w <- 8
fig_h <- 8

nest <- nest_legacy
unnest <- unnest_legacy

# Load data ---------------------------------------------------------------

load("analyze/data/cleaned_data.RData")

# Specify attribute-order and level-order ---------------------------------

Attribute_order <- c("Race/ethnicity", 
                     "Age",
                     "Gender",
                     "Graduate degree from",
                     "Prior years of relevant experience",
                     "Communication skills",
                     "Quality of writing sample",
                     "Strength of references")

Level_order <- c(c("Asian", "Black", "Hispanic", "White"),
                 c("Republican", "Democrat", "Independent"),
                 c("40", "52", "61"),
                 c("Man", "Woman"),
                 c("University of Michigan",
                   "Florida State University",
                   "Kennesaw State University",
                   "Capella University"),
                 c("5", "10", "15"),
                 c("Moderate", "Strong", "Very Strong"))

# Functions used in this script -------------------------------------------

# 1) Function to order attributes and levels

order_attributes_levels <- function(attribute, level) {
  
  attribute <- factor(attribute, levels = Attribute_order)
  level <- factor(level, levels = Level_order)
  level <- as.numeric(level)
  order1 <- as.numeric(attribute) * 1000 + level
  order2 <- rank(-order1)
  order3 <- -as.numeric(attribute) * 1000 + order2
  rank(order3)
  
}

# 2) Function to wrangle data for airplane plot

order_data_for_plot <- function(d){
  
  d %>% 
    bind_rows(data.frame(attribute = Attribute_order, stringsAsFactors = FALSE)) %>% 
    mutate(order = order_attributes_levels(attribute, level)) %>% # use Function 1
    mutate(var.names = paste0(attribute, ":"),
           var.names = ifelse(!is.na(level), paste0("   ", level), var.names))
  
}

# 3) Function to prepare data frame for plot

prepare_data_for_plot <- function(d, diff = TRUE, adjust_order = 0){
  
  data <- d
  
  out1 <- data %>% 
    filter(str_detect(position, "professor")) %>% 
    order_data_for_plot() %>% # use Function 2, which uses Function 1
    mutate(job = "Biology professor")
  
  out2 <- data %>% 
    filter(str_detect(position, "manager")) %>% 
    order_data_for_plot() %>% # use Function 2, which uses Function 1 
    mutate(job = "City manager")
  
  out3 <- data %>% 
    filter(str_detect(position, "difference")) %>% 
    order_data_for_plot() %>% # use Function 2, which uses Function 1 
    mutate(job = "Difference")
  
  if (diff == TRUE){
    out <- bind_rows(out1, out2, out3) %>% 
      mutate(order = order + adjust_order) %>% 
      mutate(yintercept = ifelse(job == "Difference", 0, 0.5))
  } else {
    out <- bind_rows(out1, out2) %>% 
      mutate(order = order + adjust_order) %>% 
      mutate(yintercept = 0.5)
    
  }
  
  return(out)
  
}

# 4) Function to customize ggplot theme

set_my_ggtheme <- function(base_size = 12, base_family = "") { 
  
  theme_few(base_size = base_size, 
            base_family = base_family) %+replace%
    theme(axis.text.x =  element_text(size = base_size, colour = "black", hjust = .5 , vjust = 1),
          axis.text.y =  element_text(size = base_size, colour = "black", hjust = 0  , vjust = 0.5),
          axis.ticks =   element_line(colour = "grey50"),
          axis.title.y = element_text(size = base_size, angle = 90, vjust = .01, hjust = .1),
          legend.position = "top")
  
}

# 5) Function to reshape data and visualize results

reshape_and_visualize_data <- function(df){
  
  # Long to wide
  df_reshaped <- df %>% 
    gather("attribute", "level", 12:19)
  
  # Run regression to calculate marginal means and save results.
  # Note: regression for each position, by each attribute, and by each level
  mm <- df_reshaped %>% 
    group_by(position, attribute, level) %>% 
    nest() %>% 
    mutate(test = map(data, ~ lm_robust(response_dum ~ 1, data = ., clusters = id)),
           tidied = map(test, tidy)) %>% 
    unnest(tidied) %>% 
    select(-term)
  
  mm %>% filter(attribute == "Race/ethnicity")
  
  # Run regression to calculate marginal means and save results.
  # Note: regression for each attribute and by each level, position as an independent variable
  mm_diff <- df_reshaped %>% 
    group_by(attribute, level) %>% 
    nest() %>% 
    mutate(test = map(data, ~ lm_robust(response_dum ~ factor(position), data = ., clusters = id)),
           tidied = map(test, tidy)) %>% 
    unnest(tidied) %>% 
    filter(term != "(Intercept)") %>% 
    select(-term) %>% 
    mutate(position = "difference")
  
  # Specify labels
  labels <- prepare_data_for_plot(mm, adjust_order = 0) %>%
    filter(job == "Biology professor") %>%
    arrange(order) %>%
    select(var.names) %>%
    pull()
  
  # Merge data frames
  vis_merged <- bind_rows(
    mm      %>% prepare_data_for_plot(diff = FALSE, adjust_order = 0),
    mm_diff %>% prepare_data_for_plot(diff = TRUE,  adjust_order = 0)
  ) %>% 
    # Add a dummy variable for significant coefficients
    mutate(sig = FALSE,
           sig = ifelse(job != "Difference" & conf.high > 0.5 & conf.low > 0.5, TRUE, sig),
           sig = ifelse(job != "Difference" & conf.high < 0.5 & conf.low < 0.5, TRUE, sig),
           sig = ifelse(job == "Difference" & p.value < 0.05, TRUE, sig))
  
  # Make a blank data to set different ylim by faceting.
  dummy_df <- bind_rows(
    data.frame(order = c(1, max(vis_merged$order)),
               estimate = c(0.35, 0.65),
               job = "Biology professor"),
    data.frame(order = c(1, max(vis_merged$order)),
               estimate = c(0.35, 0.65),
               job = "City manager"),
    data.frame(order = c(1, max(vis_merged$order)),
               estimate = c(-0.15, 0.15),
               job = "Difference")
  ) 

  # Make figure
  ggplot() + 
    # Use the above blank data-frame to make an empty figure
    # with "right" ylim() for each faceted figure
    geom_blank(data = dummy_df,
               aes(x = order, 
                   y = estimate)) + 
    facet_wrap(~ job, scales = "free_x") +
    coord_flip() +
    set_my_ggtheme() +
    labs(x = NULL,
         y = "Marginal mean and difference in marginal means") +
    # Then add real data
    geom_hline(data = vis_merged,
               aes(yintercept = yintercept),
               linetype = "dashed",
               color = "darkgray") +
    geom_pointrange(data = vis_merged,
                    aes(x = order,
                        y = estimate,
                        ymax = conf.high,
                        ymin = conf.low,
                        color = sig),
                    alpha = 0.8,
                    na.rm = TRUE) +
    scale_x_continuous(breaks = 1:length(labels),
                       labels = labels) +
    scale_color_manual(values = c("gray", "black")) +
    guides(color = "none") %>% 
    return()
  
}

# Wrangle and visualize marginal means ------------------------------------

df_all <- wave2 %>% 
  # add a response dummy
  mutate(response_dum = 0,
         response_dum = ifelse(profile == 1 & response == "Candidate 1", 1, response_dum),
         response_dum = ifelse(profile == 2 & response == "Candidate 2", 1, response_dum))

df_first <- df_all %>% 
  filter(first == position)

reshape_and_visualize_data(df_all)
ggsave("analyze/figures/MM_twoSets.pdf", width = fig_w, height = fig_h)

reshape_and_visualize_data(df_first)
ggsave("analyze/figures/MM_1stSet.pdf", width = fig_w, height = fig_h)

