#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- marginal means by something, data preparation
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)

# Load data ---------------------------------------------------------------

load("analyze/data/cleaned_data.RData")

# Total RR score using the standard 4 questions ---------------------------

racial_resentment_4items <- wave1 %>% 
  select(id, rr1, rr3, rr4, rr5) %>% 
  gather("question", "response", 2:ncol(.)) %>% 
  mutate(question = str_extract(question, "\\d") %>% as.numeric()) %>% 
  mutate(score = NA,
         score = ifelse(response == "Strongly agree", 1, score),
         score = ifelse(response == "Somewhat agree", 2, score),
         score = ifelse(response == "Neither agree nor disagree", 3, score),
         score = ifelse(response == "Somewhat disagree", 4, score),
         score = ifelse(response == "Strongly disagree", 5, score)) %>% 
  mutate(score_adjusted = NA,
         score_adjusted = ifelse(question %in% c(1, 3), 6 - score, score)) %>% 
  group_by(id) %>% 
  summarise(racial_resentment_4items = sum(score_adjusted)) %>% 
  ungroup()

# Total RR score using all the 6 questions --------------------------------

racial_resentment_6items <- wave1 %>% 
  select(id, contains("rr")) %>% 
  gather("question", "response", 2:ncol(.)) %>% 
  mutate(question = str_extract(question, "\\d") %>% as.numeric()) %>% 
  mutate(score = NA,
         score = ifelse(response == "Strongly agree", 1, score),
         score = ifelse(response == "Somewhat agree", 2, score),
         score = ifelse(response == "Neither agree nor disagree", 3, score),
         score = ifelse(response == "Somewhat disagree", 4, score),
         score = ifelse(response == "Strongly disagree", 5, score)) %>% 
  mutate(score_adjusted = NA,
         score_adjusted = ifelse(question %in% c(1, 3, 6), 6 - score, score)) %>% 
  group_by(id) %>% 
  summarise(racial_resentment_6items = sum(score_adjusted)) %>% 
  ungroup()

# Stereotype of white and black -------------------------------------------

stereotype <- wave1 %>% 
  select(id, contains("stereotype_")) %>% 
  gather("question", "response", 2:ncol(.)) %>% 
  mutate(race = if_else(str_detect(question, "black"), "black", "white"),
         question = str_extract(question, "\\d") %>% as.numeric()) %>% 
  mutate(score = NA,
         score = ifelse(response == "Extremely well", 1, score),
         score = ifelse(response == "Very well", 2, score),
         score = ifelse(response == "Moderately well", 3, score),
         score = ifelse(response == "Slightly well", 4, score),
         score = ifelse(response == "Not well at all", 5, score)) %>% 
  mutate(score_adjusted = NA,
         score_adjusted = ifelse(question %in% c(2, 4), 6 - score, score)) %>% 
  group_by(race, id) %>% 
  summarise(stereotype = sum(score_adjusted), .groups = "drop")

# White
stereotype_white <- stereotype %>%
  filter(race == "white") %>% 
  select(id, "stereotype_white" = stereotype)

# Black
stereotype_black <- stereotype %>%
  filter(race == "black") %>% 
  select(id, "stereotype_black" = stereotype)

# Difference
stereotype_diff <- stereotype_black %>% 
  left_join(stereotype_white, by = "id") %>% 
  mutate(stereotype_diff = stereotype_black - stereotype_white) %>% 
  select(id, stereotype_diff)

# Group identity ----------------------------------------------------------

# Initial wrangling
temp <- wave1 %>% 
  select(id, contains("groupID")) %>% 
  gather("question", "response", 2:ncol(.)) %>% 
  mutate(question = str_extract(question, "\\d") %>% as.numeric()) %>% 
  mutate(score = NA,
         score = ifelse(response %in% c("Extremely important", "A great deal", "Extremely strongly"), 1, score),
         score = ifelse(response %in% c("Very important", "A lot", "Very strongly"), 2, score),
         score = ifelse(response %in% c("Moderately important", "A moderate amount", "Moderately strongly"), 3, score),
         score = ifelse(response %in% c("Slightly important", "A little", "Not very strongly"), 4, score),
         score = ifelse(response %in% c("Not at all important", "Nothing at all", "None at all", "Not at all strongly"), 5, score)) %>% 
  mutate(score_adjusted = NA,
         score_adjusted = 6 - score) 
  
# Aggregate scores (using all 4 questions)
white_identity_4items <- temp %>%
  group_by(id) %>% 
  summarise(white_identity_4items = sum(score_adjusted)) %>% 
  ungroup() 

# Aggregate scores (using 3 questions)
white_identity_3items <- temp %>%
  filter(question != 4) %>% 
  group_by(id) %>% 
  summarise(white_identity_3items = sum(score_adjusted)) %>% 
  ungroup() 

# Collective guilt --------------------------------------------------------

# Initial wrangling
collective_guilt <- wave1 %>% 
  select(id, contains("collectiveguilt")) %>% 
  gather("question", "response", 2:ncol(.)) %>% 
  mutate(question = str_extract(question, "\\d") %>% as.numeric()) %>% 
  mutate(score = NA,
         score = ifelse(response %in% c("Extremely guilty", "A great deal"), 1, score),
         score = ifelse(response %in% c("Very guilty", "A lot"), 2, score),
         score = ifelse(response %in% c("Moderately guilty", "A moderate amount"), 3, score),
         score = ifelse(response %in% c("A little guilty", "A little"), 4, score),
         score = ifelse(response %in% c("Not guilty at all", "None at all"), 5, score)) %>% 
  group_by(id) %>% 
  summarise(collective_guilt  = sum(score)) %>% 
  ungroup() 

# Merge all racial attitude indicators ------------------------------------

# Keep wave1 demographic variables
demographics <- wave1 %>% 
  select(id, education, gender, race, age, region, contains("party"), ideology)

# Merge all data frames
racial_attitudes <- racial_resentment_4items %>%
  select(id, racial_resentment_4items) %>% # re-order variables
  left_join(racial_resentment_6items, by = "id") %>% 
  left_join(stereotype_diff, by = "id") %>% 
  left_join(white_identity_3items, by = "id") %>% 
  left_join(white_identity_4items, by = "id") %>% 
  left_join(collective_guilt, by = "id") 

# Wrangle data ------------------------------------------------------------

df <- wave2 %>% 
  # add a response dummy
  mutate(response_dum = 0,
         response_dum = ifelse(profile == 1 & response == "Candidate 1", 1, response_dum),
         response_dum = ifelse(profile == 2 & response == "Candidate 2", 1, response_dum)) %>% 
  # remove rr variable from wave2
  select(-contains("rr")) %>% 
  # merge demographic variable
  left_join(demographics, by = "id") %>% 
  # merge racial attitude data
  left_join(racial_attitudes, by = "id")  

# Save data ---------------------------------------------------------------

# "analyze_files" is a vector generated in `master.R`
remove(list= ls()[!(ls() %in%c('racial_attitudes','df', 'analyze_files'))])

save.image("analyze/output/cleaned_data_for_MMby.RData")
