#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- main figure (by ideology)
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()
library(ggthemes)
library(cowplot)

fig_w <- 10
fig_h <- 5
fig_s <- 1

ymin <- 0.25
ymax <- 0.75

b0 <- -250
b1 <- 1000

xlabel <- "Racial resentment scale (4 items)"

source("analyze/functions/test_hypothesis_cubic.R")
source("analyze/functions/make_figure.R")

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

# Only focus on city managers
df_m <- df %>% filter(position == "manager")

# Only focus on professors
df_p <- df %>% filter(position == "professor")

# Data wrangling ----------------------------------------------------------

d <- df %>% 
  mutate(ideology2 = NA,
         ideology2 = ifelse(ideology %in% c("Conservative", "Slightly conservative", "Extremely conservative"), "conservative", ideology2),
         ideology2 = ifelse(ideology %in% c("Liberal", "Slightly liberal", "Extremely liberal"), "liberal", ideology2)) %>% 
  filter(!is.na(ideology2), 
         `Race/ethnicity`=="Black")

d_lib <- d %>% filter(ideology2 == "liberal")
d_con <- d %>% filter(ideology2 == "conservative")

# Main results ------------------------------------------------------------

temp1_all <- test_hypothesis_cubic(d    , racial_resentment_4items, xlabel, "position")$data %>% mutate(subgroup2 = "Full Sample")
temp1_lib <- test_hypothesis_cubic(d_lib, racial_resentment_4items, xlabel, "position")$data %>% mutate(subgroup2 = "Liberals")
temp1_con <- test_hypothesis_cubic(d_con, racial_resentment_4items, xlabel, "position")$data %>% mutate(subgroup2 = "Conservatives")

out <- bind_rows(temp1_all, 
                 temp1_lib, 
                 temp1_con) %>%
  mutate(subgroup  = factor(subgroup,  labels = c("City Manager", "Biology Professor")),
         subgroup2 = factor(subgroup2, levels = c("Full Sample", "Liberals", "Conservatives"))) %>% 
  rename(term = racial_resentment_4items,
         estimate = fit.fit,
         conf.low = fit.lwr,
         conf.high = fit.upr)

# Visualize results -------------------------------------------------------

g1 <- make_figure(out) +
  facet_grid(subgroup ~ subgroup2) +
  coord_cartesian(ylim = c(ymin, ymax)) +
  scale_x_continuous(limits = c(4, 20), breaks = c(4,20)) +
  theme(axis.ticks.x = element_blank(), 
        axis.text.x  = element_blank(), 
        axis.title.x = element_blank()) +
  labs(y = "Marginal mean")

# Histogram ---------------------------------------------------------------

d_hist <- d %>% 
  select(id, ideology2, racial_resentment_4items) %>% 
  distinct()

out <- bind_rows(
  d_hist %>% 
    count(racial_resentment_4items) %>% 
    mutate(ideology2 = "all"),
  d_hist %>% 
    group_by(ideology2) %>% 
    count(racial_resentment_4items) %>% 
    ungroup()
) 

g2 <- ggplot(out) +
  geom_col(aes(y = n,
               x = racial_resentment_4items), 
           color = "white", 
           fill = "lightgray") +
  facet_grid(. ~ factor(ideology2, 
                        levels = c("all", "liberal", "conservative"),
                        labels = c("Full Sample", "Liberals", "Conservatives"))) +
  theme_few() %+%
  theme(
    strip.background = element_blank(),
    strip.text.x = element_blank()
  ) +
  scale_x_continuous(breaks = c(4, 20)) +
  labs(x = "Racial resentment scale (4 items)", 
       y = "Number of respondents")

# Merge and save figures --------------------------------------------------

plot_grid(g1, g2, ncol = 1, nrow = 2, align = "v", axis = "lr", rel_heights = 2:1)

align = ggsave("analyze/figures/MMby_ideology.pdf", width = fig_w, height = fig_h * 1.5, scale = fig_s)



