#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- main figure (by different racial attitude measures)
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()
library(ggthemes)
library(cowplot)
library(fabricatr) # split_quantile()

fig_w <- 10
fig_h <- 5
fig_s <- 1

ymin <- 0.25
ymax <- 0.75

b0 <- -250
b1 <- 1000

source("analyze/functions/test_hypothesis_cubic.R")
source("analyze/functions/test_hypothesis_3cat.R")
source("analyze/functions/make_figure_with_hist_2.R")
source("analyze/functions/custom_plot_grid.R")

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

# Only focus on city managers
df <- df %>% 
  filter(position == "manager")

# Save results ------------------------------------------------------------

xlabel <- "Racial resentment scale (6 items)"
xbreaks <- c(6, 30)
temp1 <- test_hypothesis_cubic(df, racial_resentment_6items, xlabel)
temp2 <- temp1$data %>% filter(`Race/ethnicity` == "Black")
g1 <- custom_figure_with_histogram(df, temp2, racial_resentment_6items, xlabel, xbreaks)

xlabel <- "Stereotype differences"
xbreaks <- c(-16, 16)
temp1 <- test_hypothesis_cubic(df, stereotype_diff, xlabel)
temp2 <- temp1$data %>% filter(`Race/ethnicity` == "Black")
g2 <- custom_figure_with_histogram(df, temp2, stereotype_diff, xlabel, xbreaks)

xlabel <- "White identity (3 items)"
xbreaks <- c(3, 15)
temp1 <- test_hypothesis_cubic(df, white_identity_3items, xlabel)
temp2 <- temp1$data %>% filter(`Race/ethnicity` == "Black")
g3 <- custom_figure_with_histogram(df, temp2, white_identity_3items, xlabel, xbreaks)

xlabel <- "White Identity (4 items)"
xbreaks <- c(4, 20)
temp1 <- test_hypothesis_cubic(df, white_identity_4items, xlabel)
temp2 <- temp1$data %>% filter(`Race/ethnicity` == "Black")
g4 <- custom_figure_with_histogram(df, temp2, white_identity_4items, xlabel, xbreaks)

xlabel <- "Collective guilt (reverse scaled)"
xbreaks <- c(3, 15)
xbreaks_lables <- c("15", "3")
temp1 <- test_hypothesis_cubic(df, collective_guilt, xlabel)
temp2 <- temp1$data %>% filter(`Race/ethnicity` == "Black")
g5 <- custom_figure_with_histogram(df, temp2, collective_guilt, xlabel, xbreaks, xbreaks_lables)

# Merge and save figure ---------------------------------------------------

custom_plot_grid(g2, g3, g5, adjustment = 1.165)
ggsave("analyze/figures/MMby_measures.pdf", width = fig_w, height = fig_h, scale = fig_s)

# Results using terciles --------------------------------------------------

xlabel1 <- "Stereotype differences"
temp1 <- test_hypothesis_3cat(df, stereotype_diff, xlabel1)
g1 <- temp1$data %>%
  filter(`Race/ethnicity` == "Black") %>% 
  mutate(term_chr = as.character(term),
         term = as.numeric(term), 
         measure = 1)

xlabel2 <- "White identity (3 items)"
temp2 <- test_hypothesis_3cat(df, white_identity_3items, xlabel2)
g2 <- temp2$data %>% 
  filter(`Race/ethnicity` == "Black") %>% 
  mutate(term_chr = as.character(term),
         term = as.numeric(term), 
         measure = 2)

xlabel3 <- "Collective guilt (reverse scaled)"
temp3 <- test_hypothesis_3cat(df, collective_guilt, xlabel3)
g3 <- temp3$data %>% 
  filter(`Race/ethnicity` == "Black") %>% 
  mutate(term_chr = as.character(term),
         term = as.numeric(term), 
         measure = 3) %>% 
  mutate(term_chr = case_when(term_chr == "High\n[3, 11]\n(n = 313)" ~ "High\n[15, 7]\n(n = 313)",
                              term_chr == "Medium\n[12, 14]\n(n = 271)" ~ "Medium\n[6, 4]\n(n = 271)",
                              term_chr == "Low\n[15]\n(n = 416)" ~ "Low\n[3]\n(n = 416)"))

merged_results <- bind_rows(g1, g2, g3) %>% 
  mutate(measure = factor(measure, 
                          labels = c(xlabel1, xlabel2, xlabel3)))

ggplot(merged_results) +
  geom_hline(yintercept = 0.5,
             color = "gray",
             linetype = "dashed") +
  geom_pointrange(aes(x = reorder(term_chr, term),
                      y = estimate,
                      ymin = conf.low,
                      ymax = conf.high, 
                      color = factor(sig))) +
  geom_text(aes(x = term,
                y = estimate, 
                label = format(round(estimate, digits = 2)),
                color = factor(sig)),
            nudge_x = 0.3) +
  scale_color_manual(values = c("black", "red")) +
  coord_cartesian(ylim = c(0.4, 0.6)) +
  guides(color = "none") +
  theme_few() +
  labs(title = NULL,
       x = NULL,
       y = "Marginal mean") +
  facet_wrap(~ measure, scales = "free_x")

ggsave("analyze/figures/MMby_measures_3cat.pdf", width = fig_w, height = fig_h, scale = fig_s)
