#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- reanalyze Desante (2013), Tesler (2012), Stephens-Dougan (2016), and Chudy etal (2019)
#' 
#' last update: December 15, 2021

# Initial setting ---------------------------------------------------------

library(tidyverse)
library(haven)
library(estimatr)
library(ggthemes)
suppressPackageStartupMessages(library(patchwork))

fig_w <- 8
fig_h <- 8

nest <- nest_legacy
unnest <- unnest_legacy

# Function ----------------------------------------------------------------

reanalyze <- function(data, rrvar, groupvar, depvar, ylabel, title, wgt = FALSE){
  
  rrvar_quo <- enquo(rrvar)
  groupvar_quo <- enquo(groupvar)
  depvar_quo <- enquo(depvar)
  wvar_quo <- enquo(wgt)

  if (isTRUE(wgt)){
    temp <- data %>% 
      mutate(w = weight)
  } else {
    temp <- data %>% 
      mutate(w = 1)
  } 
  
  new <- temp %>% 
    # Use the standardized variable names
    mutate(rr_var := !!rrvar_quo,
           g_var  := !!groupvar_quo,
           y_var  := !!depvar_quo) %>% 
    # listwise deletion
    select(rr_var, g_var, y_var, w) %>% 
    na.omit() %>% 
    # necessary to merge fitted values later
    arrange(g_var) 

  new1 <- new %>% 
    mutate(race = rr_var, 
           race2 = race^2,
           race3 = race^3) %>% 
    group_by(g_var) %>% 
    nest() %>% 
    mutate(test = map(data, ~ predict(lm_robust(y_var ~ 1 + race + race2 + race3, data = ., weights = w), 
                                      newdata = ., 
                                      se.fit = TRUE, 
                                      interval = "confidence") %>% 
                        as.data.frame()
    )) %>% 
    unnest(test, .drop = TRUE) %>% 
    ungroup() %>% 
    select(-g_var) %>% 
    bind_cols(new) %>% 
    select(g_var, rr_var, fit.fit, fit.lwr, fit.upr) %>% 
    distinct() %>% 
    mutate(sig = FALSE,
           sig = ifelse(fit.lwr > 0.5 & fit.upr > 0.5, TRUE, sig),
           sig = ifelse(fit.lwr < 0.5 & fit.upr < 0.5, TRUE, sig)) %>% 
    mutate(subgroup = "") %>% 
    mutate(g_var_fct = factor(g_var) %>% as.numeric(),
           rr_var_adj = ifelse(g_var == 1, rr_var + 0.005, rr_var - 0.005))
  
  xmin <- new1 %>% select(rr_var) %>% pull() %>% min(.)
  xmax <- new1 %>% select(rr_var) %>% pull() %>% max(.)
  
  ggplot(new1) +
    geom_pointrange(aes(x = rr_var_adj, 
                        y = fit.fit, 
                        ymin = fit.lwr,
                        ymax = fit.upr, 
                        color = factor(g_var))) +
    scale_color_manual(values = c("black", "red")) +
    scale_x_continuous(breaks = c(xmin, xmax)) +
    labs(y = ylabel, 
         x = "Racial resentment",
         color = "Race",
         title = title) + 
    theme_few() +
    theme(legend.position = c(.925, .85),
          legend.title = element_blank(),
          plot.title = element_text(size = 13),
          axis.title = element_text(size = 10))
  
  
}

# Destante (2013) ---------------------------------------------------------

df1 <- read_dta("analyze/data/desante_experimental_data.dta") %>%
  mutate_if(is.labelled, as_factor) %>%
  
  # code applicant race treatments
  mutate(app1black = case_when(treatment %in% c(10,11,12) ~ 1,
                               TRUE ~ 0),
         app2black = case_when(treatment %in% c(7,8,9,10,11,12) ~ 1,
                               TRUE ~ 0),
         app1white = case_when(treatment %in% c(4,5,6,7,8,9) ~ 1,
                               TRUE ~ 0),
         app2white = case_when(treatment %in% c(4,5,6) ~ 1,
                               TRUE ~ 0),
         
         # code racial resentment (transferring directly to 0-1 scale)
         rr1 = case_when(dkd321=="Agree strongly" ~ 1,
                         dkd321=="Agree somewhat" ~ 0.75,
                         dkd321=="Neither agree nor disagree" ~ 0.5,
                         dkd321=="Disagree somewhat" ~ 0.25,
                         dkd321=="Disagree strongly" ~ 0),
         rr2 = case_when(dkd322=="Agree strongly" ~ 0,
                         dkd322=="Agree somewhat" ~ 0.25,
                         dkd322=="Neither agree nor disagree" ~ 0.5,
                         dkd322=="Disagree somewhat" ~ 0.75,
                         dkd322=="Disagree strongly" ~ 1),
         rr3 = case_when(dkd323=="Agree strongly" ~ 1,
                         dkd323=="Agree somewhat" ~ 0.75,
                         dkd323=="Neither agree nor disagree" ~ 0.5,
                         dkd323=="Disagree somewhat" ~ 0.25,
                         dkd323=="Disagree strongly" ~ 0),
         rr4 = case_when(dkd324=="Agree strongly" ~ 0,
                         dkd324=="Agree somewhat" ~ 0.25,
                         dkd324=="Neither agree nor disagree" ~ 0.5,
                         dkd324=="Disagree somewhat" ~ 0.75,
                         dkd324=="Disagree strongly" ~ 1),
         rr = (rr1+rr2+rr3+rr4)/4,
         
         # Save unique ID number for each respondent
         idno = row_number()) %>%
  
  # Remove observations with missing RR values
  filter(!is.na(rr)) %>% 
  
  # Subset to relevant variables
  select(idno, treatment, contains("app"), rr) %>%
  rename(deficit = app3) %>%
  
  # Reshape data from wide to long
  gather(key = "set", value = "app", "app1":"app2") %>%
  
  # Save applicant number
  mutate(set = as.numeric(str_sub(set, 4, 4)),
         
         # Code new variables
         # Indicators for if either of the applicant numbers are black (white)
         appblack = case_when(set==1 & app1black==1 ~ 1,
                              set==2 & app2black==1 ~ 1,
                              TRUE ~ 0),
         appwhite = case_when(set==1 & app1white==1 ~ 1,
                              set==2 & app2white==1 ~ 1,
                              TRUE ~ 0),
         # Number of black (white) applicant sets; should range from 0 to 2
         numbblack = app1black + app2black,
         numbwhite = app1white + app2white) %>% 
  
  # Remove repeat observations on each individual (deficit will be the same anyways)
  filter(set==1, 
         # Remove cases with both black applicants 
         # This results in the numbblack variable capturing the effect of going from no black applicants to applicant 1 being black
         numbblack!=2) %>%
  mutate(allocate = 1500 - deficit, # Create variable to measure amount allocated to both applicants
         numbblack = as.character(numbblack)) # Make numbblack character; will be either 0 or 1 now

fig1 <- reanalyze(df1, 
                  rr, 
                  numbblack, 
                  allocate,
                  "Allocated money", 
                  "Money allocated to the applicants (vs. for offsetting\ndeficit) for no black applicants (0) and first applicant\nbeing black (1)")

# Tesler (2012) -----------------------------------------------------------

df2 <- read_dta("analyze/data/CCAP 2009 Reinterviews.dta") %>%
  mutate_if(is.labelled, as_factor) %>% 
  
  # create obama (1) vs. cong-dems (0) treatment variable for stimulus experiment
  mutate(obamatreat = case_when(surveygroup=="D" ~ 1,
                                surveygroup=="C" ~ 0,
                                TRUE ~ NA_real_), 
         obamatreat = as.factor(obamatreat)) %>% 
  
  # Remove observations with missing RR values and subset to whites only
  filter(!is.na(resent_ave), white == 1) %>% 
  filter(!is.na(obamatreat))

fig2 <- reanalyze(df2, 
                  resent_ave, 
                  obamatreat, 
                  stimulus0,
                  "Pr(stimulus package was a good idea)", 
                  "Probability of thinking the stimulus package was a\ngood idea by Cong. Democrats attribution (0) vs.\nObama attribution (1)", 
                  TRUE)

# Stephens-Dougan (2016) --------------------------------------------------

df3 <- read_dta("analyze/data/StephensData_JOP.dta") %>%
  mutate_if(is.labelled, as_factor) %>% 
  
  # create treatment variable for a mailer that includes all or some blacks (1) vs. no blacks (0); also for republican (vs. democratic) candidate
  mutate(withblacks = case_when(whitedem_blacks==1 | whitedem_diverse==1 ~ 1,
                                whiterepub_blacks==1 | whiterepub_diverse==1 ~ 1,
                                whitedem_whites==1 | whiterepub_whites==1 ~ 0),
         withblacks = as.factor(withblacks),
         
         # recode vote likelihood outcome (votegdavis) to 0 (very unlikely) to 1 (very likley) scale
         vote = case_when(votegdavis==0 ~ 0,
                          votegdavis==1 ~ 1/3,
                          votegdavis==2 ~ 2/3,
                          votegdavis==3 ~ 1,
                          TRUE ~ NA_real_))

fig3 <- reanalyze(df3, 
                  raceresentscale, 
                  withblacks, 
                  vote,
                  "Vote likelihood for the candidate", 
                  "Vote likelihood for the candidate by all-white\ncampaign mailers (0) vs. mailers with blacks (1)")

# Chudy etal (2019) -------------------------------------------------------

# Note:
# Error found in `constructing+2014+SSI.do` file from dataverse.
# One item (q294) was used for two different RRS items (see lines 31-43 in original do file).
# It is unclear where the 4th unique RRS item is, so we can only use 3 items for our RRS average.
# We remove one of the duplicate items going into the average below.
# Because the two duplicate items run in the same direction of the scale, they involve the same coding (i.e. we know what high/low numbers mean even if we don't know which item it is).

df4 <- read_dta("analyze/data/2014+SSI+constructed+data.dta") %>%
  mutate_if(is.labelled, as_factor) %>%
  # Need to create new RRS index from 3 items
  # blackslavery0to1 and blackdeserve0to1 are the duplicates - remove blackdeserve0to1
  # Taking an average for simplicity (reverse code - unclear about which side is which, but this matches their stata code better)
  mutate(raceres = 1 - ((blackfavors0to1 + blackslavery0to1 + blacktry0to1) / 3)) %>% 

  # Subset to rwhite==1
  # unclear what this variable is, but "analyses.do" does this in the relevant regression (line 88)
  filter(rwhite==1, !is.na(black))

fig4 <- reanalyze(df4, 
                  raceres, 
                  black, 
                  larsonvote,
                  "Vote intention for the candidate", 
                  "Vote intention for the candidate by candidate\nrace being white (0) vs. black (1)")

# Combine all figures -----------------------------------------------------

(fig1 | fig2) / (fig3 | fig4)

# Save figure
ggsave("analyze/figures/reanalyses-combined.pdf", width = 10, height = 8)

