#' Agadjanian-Carey-Horiuchi-Ryan
#' Build -- Read and wrangle the Wave 1 data
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

suppressPackageStartupMessages(library(tidyverse))
suppressPackageStartupMessages(library(lubridate)) # ymd_hms()

source("build/functions/read_Survey.R")

# Read data ---------------------------------------------------------------

# Specify file names.
file_text    <- "build/data/ACHR_Wave_1 - choice text (after data collection was paused on November 5).csv"
file_numeric <- "build/data/ACHR_Wave_1 - numeric values (after data collection was paused on November 5).csv"

# Read data and assign the row number.
temp <- read_Survey(file_text) %>% 
  mutate(id = row_number()) 

# Check the first observation with gc == 1.
# By mistake in Qualtrics' survey flow, all observations before this observation are not usable. 
# Qualtrics project manager fixed this after the launch. we only use observations after this fix.
first_obs <- temp %>% 
  # Q11.1 is an attention check question. The project manager made a mistake in setting the 
  # screening conditions. Uncheck the following line to check the errors.
  #select(id, contains("Q11.1"), gc, term) %>% 
  filter(gc == 1) %>% 
  summarize(first_gc1 = min(id)) %>% 
  pull()

first_obs

# Filter out invalid observations before the attention-check setting was fixed.
df_text <- temp %>% 
  select(-X) %>% 
  filter(id >= first_obs)

# Make another data-frame using numeric values.
df_numeric <- read_Survey(file_numeric) %>% 
  mutate(id = row_number()) %>% 
  select(-X) %>% 
  filter(id >= first_obs)

# Make a data-frame with supposedly "good complete" responses -------------

gc_numeric <- df_numeric %>% 
  # the first screen presented 
  filter(!is.na(Q1.1)) %>% 
  # agree to participate
  filter(Q1.2 == 1) %>% 
  # isNew is either "True" or "" 
  filter(isNew != "False") %>% 
  # white respondents
  filter(Q2.4 == 5) %>% 
  # answer the attention-check questions correctly
  filter(Q11.1_1 == 1 & is.na(Q11.1_2) & is.na(Q11.1_3) & is.na(Q11.1_4) & Q11.1_5 == 1) %>% 
  # the last screen presented
  filter(!is.na(Q30.2)) %>% 
  # not speeder
  filter(term != "sd")

# Check duplicates --------------------------------------------------------

# rid
gc_numeric %>% 
  select(gc, term, isNew, rid) %>% 
  count(gc, term, isNew, rid) %>% 
  filter(n != 1) %>% 
  nrow()

# ResponseID
gc_numeric %>% 
  select(gc, term, isNew, ResponseID) %>% 
  count(gc, term, isNew, ResponseID) %>% 
  filter(n != 1) %>% 
  nrow()

# IP address  
gc_numeric %>% 
  select(gc, term, isNew, V6) %>% 
  count(gc, term, isNew, V6) %>% 
  filter(n != 1) %>% 
  nrow()

# Check gc, term, isNew ---------------------------------------------------
# We decided to use over-quota observations as long as they are "good completes."

gc_numeric %>% count(gc, term) 

# Save valid responses ----------------------------------------------------

gc_numeric %>% 
  select(rid, gc, term, V8, V9) %>% 
  write_csv("build/output/wave1_ToBeRecontacted.csv")

# Save comments -----------------------------------------------------------

gc_numeric %>% 
  select(V1, V8, V9, id, gc, term, Q30.1) %>% 
  write_csv("build/output/wave1_comments.csv")

# Time to complete the survey ---------------------------------------------

gc_numeric %>% 
  mutate(time = ymd_hms(V9) - ymd_hms(V8)) %>% 
  summarize(min = min(time),
            max = max(time),
            median = median(time),
            mean = mean(time)) %>% 
  write_csv("build/output/wave1_time.csv")

# The survey period -------------------------------------------------------

gc_numeric %>% 
  mutate(End = V9) %>% 
  summarise(first_obs_recorded = min(End),
            last_obs_recorded = max(End)) %>% 
  write_csv("build/output/wave1_period.csv")

# Check Qualtrics's quality control ---------------------------------------

gc_numeric %>% 
  count(Q_RecaptchaScore, gc, term) # all good (>= 0.7)

# Save RDS data -----------------------------------------------------------

gc_text <- gc_numeric %>% 
  select(rid) %>% 
  left_join(df_text, by = "rid")

saveRDS(gc_text,    "build/output/wave1_cleaned_text.RDS")
saveRDS(gc_numeric, "build/output/wave1_cleaned.RDS")




