#' Agadjanian-Carey-Horiuchi-Ryan
#' Build -- Read and wrangle the Wave 2 data
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse) 
library(lubridate) # ymd_hms()

source("build/functions/read_Survey.R")
source("build/functions/subset_data.R")
source("build/functions/reshape_conjoint.R")

# Read data ---------------------------------------------------------------

# Specify file names.
file_numeric <- "build/data/ACHR_Wave_2 - numeric values.csv"
file_text    <- "build/data/ACHR_Wave_2 - choice text.csv"

# Read data.
df_numeric <- read_Survey(file_numeric) %>% select(-X) 
df_text    <- read_Survey(file_text) %>% select(-X) 

# Remove the second attempt of duplicated IDs -----------------------------

duplicated <- df_text %>% 
  select(OriginalRID) %>% 
  mutate(dup = duplicated(OriginalRID)) %>% 
  filter(dup == TRUE) %>% 
  select(OriginalRID) %>% 
  pull()

duplicated

df_text_updated <- df_text %>% 
  group_by(OriginalRID) %>% 
  mutate(start = lubridate::ymd_hms(V8), 
         start_min = min(start), 
         keep = ifelse(start == start_min, 1, 0)) %>% 
  ungroup() %>% 
  filter(keep == 1)

# Check again.
df_text_updated %>% 
  select(OriginalRID) %>% 
  mutate(dup = duplicated(OriginalRID)) %>% 
  filter(dup == TRUE) %>% 
  select(OriginalRID) %>% 
  pull()

# Wrangle data ------------------------------------------------------------

# Make a character vector for response questions.
fst_ten <- paste0("Q3.", seq(from = 2, to = 20, by = 2))
snd_ten <- paste0("Q5.", seq(from = 2, to = 20, by = 2))

# Save conjoint elements of the first 10 tasks.
fst_conjoint <- df_text_updated %>% 
  select("id" = OriginalRID, 
         contains("B.1."), contains("B.2."), contains("B.3."), contains("B.4."), contains("B.5."), 
         contains("B.6."), contains("B.7."), contains("B.8."), contains("B.9."), contains("B.10."))

# Save conjoint elements of the second 10 tasks.
snd_conjoint <- df_text_updated %>% 
  select("id" = OriginalRID, 
         contains("B.11."), contains("B.12."), contains("B.13."), contains("B.14."), contains("B.15."), 
         contains("B.16."), contains("B.17."), contains("B.18."), contains("B.19."), contains("B.20.")) %>% 
  # Rename all embedded codes so that the first and second tasks all have the same codes
  set_names(names(fst_conjoint))

# Reshape all data by the position and by the order.
df_text_reshaped <- bind_rows(
  subset_data(df_text_updated, "professor", "professor"),
  subset_data(df_text_updated, "professor", "manager"),
  subset_data(df_text_updated, "manager", "manager"),
  subset_data(df_text_updated, "manager", "professor")
)

# Check blank conjoint tables ---------------------------------------------

blank_conjoint <- df_text_reshaped %>%
  select(id, position, contains("B.")) %>% 
  gather("code", "name", 3:ncol(.)) %>% 
  filter(name == "") %>% 
  count(id) %>% 
  select(id) %>% 
  pull()

blank_conjoint # blank conjoint table

# Re-shape data for conjoint analysis -------------------------------------

conjoint_text <- df_text_reshaped  %>% 
  
  # Remove cases in which blank conjoint tables were shown.
  filter(!(id %in% blank_conjoint)) %>% 
  
  # Then, reshape.
  reshape_conjoint()

# Merge all data ----------------------------------------------------------

wave2_cleaned_text <- df_text_updated %>% 
  
  # Remove cases in which blank conjoint tables were shown.
  filter(!(OriginalRID %in% blank_conjoint)) %>% 
  
  # Then, select and rename variables.
  select("id" = OriginalRID, 
         "rr1" = Q7.1,
         "rr2" = Q8.1,
         "rr3" = Q9.1,
         "rr4" = Q10.1,
         "rr5" = Q11.1,
         "rr6" = Q12.1,
         first
  ) %>% 
  
  # Then, merge. 
  right_join(conjoint_text, by = "id")

# Save comments -----------------------------------------------------------

df_text_updated %>% 
  # Remove cases in which blank conjoint tables were shown.
  filter(!(OriginalRID %in% blank_conjoint)) %>% 
  select(OriginalRID, first, position, Q13.1) %>% 
  write_csv("build/output/wave2_comments.csv")

# Time to complete --------------------------------------------------------

df_text_updated %>% 
  # Remove cases in which blank conjoint tables were shown.
  filter(!(OriginalRID %in% blank_conjoint)) %>% 
  mutate(length = ymd_hms(V9) - ymd_hms(V8)) %>% 
  summarise(min = min(length), 
            mean = mean(length),
            median = median(length), 
            max = max(length)) %>% 
  write_csv("build/output/wave2_time.csv")

# The survey period -------------------------------------------------------

df_text_updated %>% 
  # Remove cases in which blank conjoint tables were shown.
  filter(!(OriginalRID %in% blank_conjoint)) %>% 
  mutate(End = V9) %>% 
  summarise(first_obs_recorded = min(End),
            last_obs_recorded = max(End)) %>% 
  write_csv("build/output/wave2_period.csv")

# Position of Race/Ethnicity ----------------------------------------------

position <- df_text_updated %>% 
  select(OriginalRID, paste0("B.1.", 1:8)) %>% 
  pivot_longer(2:ncol(.)) %>% 
  filter(value == "Race/ethnicity") %>% 
  mutate(re_position = str_replace_all(name, "B.1.", "") %>% as.numeric()) %>% 
  select("id" = OriginalRID, re_position)
  
final <- wave2_cleaned_text %>% 
  left_join(position, by = "id")

# Save data ---------------------------------------------------------------

saveRDS(final, "build/output/wave2_cleaned_text.RDS")







