#' Agadjanian-Carey-Horiuchi-Ryan
#' Build -- merge and clean the Wave 1 and Wave 2 data
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse) 

# Identify good completes in both waves -----------------------------------

# Keep ID for wave 2 good completes.
wave2_completes <- readRDS("build/output/wave2_cleaned_text.RDS") %>% 
  select(id) %>% 
  distinct() %>% 
  pull()

wave1 <- readRDS("build/output/wave1_cleaned_text.RDS") %>% 
  select("id" = rid) %>% 
  filter(id %in% c(wave2_completes)) %>% 
  mutate(wave = 1)

wave2 <- readRDS("build/output/wave2_cleaned_text.RDS") %>% 
  mutate(wave = 2)

# Check strange id in wave 2.
wave1_id <- wave1 %>% select(id) %>% distinct() %>% mutate(wave1 = 1)
wave2_id <- wave2 %>% select(id) %>% distinct() %>% mutate(wave2 = 1)
left_join(wave2_id, wave1_id, by ="id") %>% 
  filter(is.na(wave1))

# Save good completes: exclude responses recorded only in wave 2
good_completes <- wave1_id %>% select(id) %>% pull()

# [Wave 1] Load and wrangle data ------------------------------------------

wave1 <- readRDS("build/output/wave1_cleaned_text.RDS") %>% 
  
  # Select variables used and rename them (if necessary).
  select(-c(1:35), # Qualtrics parameters and embedded fields
         -id, # assigned for cleaning purpose
         id = rid,
         race1 = race1_singular,
         race2 = race2_singular,
         -contains("_plural"),
         -Q1.1,
         -Q1.2, 
         -Q2.1, 
         education = Q2.2,
         gender = Q2.3,
         race = Q2.4,
         age = Q2.5,
         region = Q2.6,
         party = Q2.7,
         party_leaning = Q2.8,
         party_strength = Q2.9,
         ideology = Q2.10,
         -Q3.1,
         rr1 = Q4.1,
         rr2 = Q5.1, # Not used
         rr3 = Q6.1,
         rr4 = Q7.1, 
         rr5 = Q8.1,
         rr6 = Q9.1, # Not used
         -Q10.1,
         occupation1 = Q10.2_1,
         occupation2 = Q10.2_2,
         occupation3 = Q10.2_3,
         occupation4 = Q10.2_4,
         occupation5 = Q10.2_5,
         occupation6 = Q10.2_6,
         -contains("Q11.1"), # screener (all passed)
         -Q12.1,
         stereotype1_1 = Q13.1,
         stereotype1_2 = Q14.1,
         stereotype1_3 = Q15.1,
         stereotype1_4 = Q16.1,
         -Q17.1,
         stereotype2_1 = Q18.1,
         stereotype2_2 = Q19.1,
         stereotype2_3 = Q20.1,
         stereotype2_4 = Q21.1,
         -Q22.1,
         groupID1 = Q23.1,
         groupID2 = Q24.1,
         groupID3 = Q25.1,
         groupID4 = Q26.1,
         collectiveguilt1 = Q27.1,
         collectiveguilt2 = Q28.1,
         collectiveguilt3 = Q29.1,
         -Q30.1,
         -Q30.2,
         - contains("Location")) %>% 
  
  # Select good completes only.
  filter(id %in% c(good_completes)) %>% 
  
  # Re-order variables.
  select(id, everything()) %>% 
  
  # Remake stereotype variables.
  mutate(stereotype_white1 = ifelse(race1 =="white", stereotype1_1, stereotype2_1),
         stereotype_white2 = ifelse(race1 =="white", stereotype1_2, stereotype2_2),
         stereotype_white3 = ifelse(race1 =="white", stereotype1_3, stereotype2_3),
         stereotype_white4 = ifelse(race1 =="white", stereotype1_4, stereotype2_4),
         stereotype_black1 = ifelse(race1 =="black", stereotype1_1, stereotype2_1),
         stereotype_black2 = ifelse(race1 =="black", stereotype1_2, stereotype2_2),
         stereotype_black3 = ifelse(race1 =="black", stereotype1_3, stereotype2_3),
         stereotype_black4 = ifelse(race1 =="black", stereotype1_4, stereotype2_4)) %>% 
  select(-contains("stereotype1_"), -contains("stereotype2_"))

# [Wave 2] Load and wrangle data ------------------------------------------

wave2 <- readRDS("build/output/wave2_cleaned_text.RDS") %>% 
  filter(id %in% c(good_completes))

# Save image --------------------------------------------------------------

remove(wave2_completes)
save.image("analyze/data/cleaned_data.RData")

# Check whether conjoint levels for race are always different -------------

wave2 %>% 
  select(id, position, task, profile, `Race/ethnicity`) %>% 
  arrange(id, position, task, profile) %>% 
  pivot_wider(id_cols = c(id, position, task), names_from = profile, values_from = `Race/ethnicity`) %>% 
  mutate(combination = paste(`1`, ",", `2`)) %>% 
  count(combination)

